Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Elemental MediaLive.

Actions, resources, and condition keys for AWS Elemental MediaLive - Service Authorization Reference

# Actions, resources, and condition keys for AWS Elemental MediaLive

AWS Elemental MediaLive (service prefix: `medialive` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS Elemental MediaLive
- Resource types defined by AWS Elemental MediaLive
- Condition keys for AWS Elemental MediaLive

## Actions defined by AWS Elemental MediaLive

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AcceptInputDeviceTransfer | Grants permission to accept an input device transfer | Write | input-device* |  |
BatchDelete | Grants permission to delete channels, inputs, input security groups, and multiplexes | Write |  |  |
BatchStart | Grants permission to start channels and multiplexes | Write |  |  |
BatchStop | Grants permission to stop channels and multiplexes | Write |  |  |
BatchUpdateSchedule | Grants permission to add and remove actions from a channel's schedule | Write | channel* |  |
CancelInputDeviceTransfer | Grants permission to cancel an input device transfer | Write | input-device* |  |
ClaimDevice | Grants permission to claim an input device | Write | input-device* |  |
CreateChannel | Grants permission to create a channel | Write | channel* |  |
input* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateInput | Grants permission to create an input | Write | input* |  |
input-security-group* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateInputSecurityGroup | Grants permission to create an input security group | Write | input-security-group* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateMultiplex | Grants permission to create a multiplex | Write | multiplex* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateMultiplexProgram | Grants permission to create a multiplex program | Write | multiplex* |  |
CreatePartnerInput | Grants permission to create a partner input | Write | input* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateTags | Grants permission to create tags for channels, inputs, input security groups, multiplexes, and reservations | Tagging | channel |  |
input |  |
input-security-group |  |
multiplex |  |
reservation |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
DeleteChannel | Grants permission to delete a channel | Write | channel* |  |
DeleteInput | Grants permission to delete an input | Write | input* |  |
DeleteInputSecurityGroup | Grants permission to delete an input security group | Write | input-security-group* |  |
DeleteMultiplex | Grants permission to delete a multiplex | Write | multiplex* |  |
DeleteMultiplexProgram | Grants permission to delete a multiplex program | Write | multiplex* |  |
DeleteReservation | Grants permission to delete an expired reservation | Write | reservation* |  |
DeleteSchedule | Grants permission to delete all schedule actions for a channel | Write | channel* |  |
DeleteTags | Grants permission to delete tags from channels, inputs, input security groups, multiplexes, and reservations | Tagging | channel |  |
input |  |
input-security-group |  |
multiplex |  |
reservation |  |
| aws:TagKeys |
DescribeChannel | Grants permission to get details about a channel | Read | channel* |  |
DescribeInput | Grants permission to describe an input | Read | input* |  |
DescribeInputDevice | Grants permission to describe an input device | Read | input-device* |  |
DescribeInputDeviceThumbnail | Grants permission to describe an input device thumbnail | Read | input-device* |  |
DescribeInputSecurityGroup | Grants permission to describe an input security group | Read | input-security-group* |  |
DescribeMultiplex | Grants permission to describe a multiplex | Read | multiplex* |  |
DescribeMultiplexProgram | Grants permission to describe a multiplex program | Read | multiplex* |  |
DescribeOffering | Grants permission to get details about a reservation offering | Read | offering* |  |
DescribeReservation | Grants permission to get details about a reservation | Read | reservation* |  |
DescribeSchedule | Grants permission to view a list of actions scheduled on a channel | Read | channel* |  |
ListChannels | Grants permission to list channels | List |  |  |
ListInputDeviceTransfers | Grants permission to list input device transfers | List |  |  |
ListInputDevices | Grants permission to list input devices | List |  |  |
ListInputSecurityGroups | Grants permission to list input security groups | List |  |  |
ListInputs | Grants permission to list inputs | List |  |  |
ListMultiplexPrograms | Grants permission to list multiplex programs | List |  |  |
ListMultiplexes | Grants permission to list multiplexes | List |  |  |
ListOfferings | Grants permission to list reservation offerings | List |  |  |
ListReservations | Grants permission to list reservations | List |  |  |
ListTagsForResource | Grants permission to list tags for channels, inputs, input security groups, multiplexes, and reservations | List | channel |  |
input |  |
input-security-group |  |
multiplex |  |
reservation |  |
PurchaseOffering | Grants permission to purchase a reservation offering | Write | offering* |  |
reservation* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
RejectInputDeviceTransfer | Grants permission to reject an input device transfer | Write | input-device* |  |
StartChannel | Grants permission to start a channel | Write | channel* |  |
StartMultiplex | Grants permission to start a multiplex | Write | multiplex* |  |
StopChannel | Grants permission to stop a channel | Write | channel* |  |
StopMultiplex | Grants permission to stop a multiplex | Write | multiplex* |  |
TransferInputDevice | Grants permission to transfer an input device | Write | input-device* |  |
UpdateChannel | Grants permission to update a channel | Write | channel* |  |
UpdateChannelClass | Grants permission to update the class of a channel | Write | channel* |  |
UpdateInput | Grants permission to update an input | Write | input* |  |
UpdateInputDevice | Grants permission to update an input device | Write | input-device* |  |
UpdateInputSecurityGroup | Grants permission to update an input security group | Write | input-security-group* |  |
UpdateMultiplex | Grants permission to update a multiplex | Write | multiplex* |  |
UpdateMultiplexProgram | Grants permission to update a multiplex program | Write | multiplex* |  |
UpdateReservation | Grants permission to update a reservation | Write | reservation* |  |

## Resource types defined by AWS Elemental MediaLive

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
channel | `arn:$ { Partition}:medialive:$ { Region}:$ { Account}:channel:*` | aws:ResourceTag/${TagKey}
input | `arn:$ { Partition}:medialive:$ { Region}:$ { Account}:input:*` | aws:ResourceTag/${TagKey}
input-device | `arn:$ { Partition}:medialive:$ { Region}:$ { Account}:inputDevice:*` |
input-security-group | `arn:$ { Partition}:medialive:$ { Region}:$ { Account}:inputSecurityGroup:*` | aws:ResourceTag/${TagKey}
multiplex | `arn:$ { Partition}:medialive:$ { Region}:$ { Account}:multiplex:*` | aws:ResourceTag/${TagKey}
reservation | `arn:$ { Partition}:medialive:$ { Region}:$ { Account}:reservation:*` | aws:ResourceTag/${TagKey}
offering | `arn:$ { Partition}:medialive:$ { Region}:$ { Account}:offering:*` |

## Condition keys for AWS Elemental MediaLive

AWS Elemental MediaLive defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | The tag for a MediaLive request | String
aws:ResourceTag/${TagKey} | The tag for a MediaLive resource | String
aws:TagKeys | The tag keys for a MediaLive resource or request | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.